diff --git a/src/Tgstation.Server.Api/Models/ChatSettings.cs b/src/Tgstation.Server.Api/Models/ChatBot.cs
similarity index 84%
rename from src/Tgstation.Server.Api/Models/ChatSettings.cs
rename to src/Tgstation.Server.Api/Models/ChatBot.cs
index f613a4484a..7c1ee41dd0 100644
--- a/src/Tgstation.Server.Api/Models/ChatSettings.cs
+++ b/src/Tgstation.Server.Api/Models/ChatBot.cs
@@ -6,16 +6,16 @@ using Tgstation.Server.Api.Rights;
namespace Tgstation.Server.Api.Models
{
///
- public sealed class ChatSettings : Internal.ChatSettings
+ public sealed class ChatBot : Internal.ChatBot
{
///
/// Channels the Discord bot should listen/announce in
///
- [Permissions(WriteRight = ChatSettingsRights.WriteChannels)]
+ [Permissions(WriteRight = ChatBotRights.WriteChannels)]
public List Channels { get; set; }
///
- /// Validates are correct for the
+ /// Validates are correct for the
///
///
public bool ValidateProviderChannelTypes()
diff --git a/src/Tgstation.Server.Api/Models/InstanceUser.cs b/src/Tgstation.Server.Api/Models/InstanceUser.cs
index 68bd323b81..14727e9812 100644
--- a/src/Tgstation.Server.Api/Models/InstanceUser.cs
+++ b/src/Tgstation.Server.Api/Models/InstanceUser.cs
@@ -47,10 +47,10 @@ namespace Tgstation.Server.Api.Models
public RepositoryRights? RepositoryRights { get; set; }
///
- /// The of the
+ /// The of the
///
[Required]
- public ChatSettingsRights? ChatSettingsRights { get; set; }
+ public ChatBotRights? ChatBotRights { get; set; }
///
/// The of the
diff --git a/src/Tgstation.Server.Api/Models/Internal/ChatSettings.cs b/src/Tgstation.Server.Api/Models/Internal/ChatBot.cs
similarity index 64%
rename from src/Tgstation.Server.Api/Models/Internal/ChatSettings.cs
rename to src/Tgstation.Server.Api/Models/Internal/ChatBot.cs
index 2a23052ad8..87e7083b64 100644
--- a/src/Tgstation.Server.Api/Models/Internal/ChatSettings.cs
+++ b/src/Tgstation.Server.Api/Models/Internal/ChatBot.cs
@@ -6,8 +6,8 @@ namespace Tgstation.Server.Api.Models.Internal
///
/// Manage the server chat bots
///
- [Model(RightsType.ChatSettings, RequiresInstance = true, CanList = true, CanCrud = true, ReadRight = ChatSettingsRights.Read)]
- public class ChatSettings
+ [Model(RightsType.ChatBots, RequiresInstance = true, CanList = true, CanCrud = true, ReadRight = ChatBotRights.Read)]
+ public class ChatBot
{
///
/// The settings id
@@ -18,26 +18,26 @@ namespace Tgstation.Server.Api.Models.Internal
///
/// The name of the connection
///
- [Permissions(WriteRight = ChatSettingsRights.WriteName)]
+ [Permissions(WriteRight = ChatBotRights.WriteName)]
[Required]
public string Name { get; set; }
///
/// If the connection is enabled
///
- [Permissions(WriteRight = ChatSettingsRights.WriteEnabled)]
+ [Permissions(WriteRight = ChatBotRights.WriteEnabled)]
public bool? Enabled { get; set; }
///
/// The used for the connection
///
- [Permissions(WriteRight = ChatSettingsRights.WriteProvider)]
+ [Permissions(WriteRight = ChatBotRights.WriteProvider)]
public ChatProvider? Provider { get; set; }
///
/// The information used to connect to the
///
- [Permissions(ReadRight = ChatSettingsRights.ReadConnectionString, WriteRight = ChatSettingsRights.ReadConnectionString)]
+ [Permissions(ReadRight = ChatBotRights.ReadConnectionString, WriteRight = ChatBotRights.ReadConnectionString)]
[Required]
public string ConnectionString { get; set; }
}
diff --git a/src/Tgstation.Server.Api/Rights/ChatSettingsRights.cs b/src/Tgstation.Server.Api/Rights/ChatBotRights.cs
similarity index 50%
rename from src/Tgstation.Server.Api/Rights/ChatSettingsRights.cs
rename to src/Tgstation.Server.Api/Rights/ChatBotRights.cs
index 9064bda79c..d9a8c61ff1 100644
--- a/src/Tgstation.Server.Api/Rights/ChatSettingsRights.cs
+++ b/src/Tgstation.Server.Api/Rights/ChatBotRights.cs
@@ -3,49 +3,49 @@
namespace Tgstation.Server.Api.Rights
{
///
- /// Rights for
+ /// Rights for
///
[Flags]
- public enum ChatSettingsRights : ulong
+ public enum ChatBotRights : ulong
{
///
/// User has no rights
///
None = 0,
///
- /// User can change
+ /// User can change
///
WriteEnabled = 1,
///
- /// User can change
+ /// User can change
///
WriteProvider = 2,
///
- /// User can change
+ /// User can change
///
WriteChannels = 4,
///
- /// User can change
+ /// User can change
///
WriteConnectionString = 8,
///
- /// User can read requires
+ /// User can read requires
///
ReadConnectionString = 16,
///
- /// User can read all chat settings except
+ /// User can read all chat settings except
///
Read = 32,
///
- /// User can change
+ /// User can change
///
WriteName = 32,
///
- /// User can create new
+ /// User can create new
///
Create = 64,
///
- /// User can delete
+ /// User can delete
///
Delete = 128
}
diff --git a/src/Tgstation.Server.Api/Rights/RightsHelper.cs b/src/Tgstation.Server.Api/Rights/RightsHelper.cs
index cbd83a7ca5..7c4a9cfa5a 100644
--- a/src/Tgstation.Server.Api/Rights/RightsHelper.cs
+++ b/src/Tgstation.Server.Api/Rights/RightsHelper.cs
@@ -21,7 +21,7 @@ namespace Tgstation.Server.Api.Rights
{ RightsType.Byond, typeof(ByondRights) },
{ RightsType.DreamMaker, typeof(DreamMakerRights) },
{ RightsType.DreamDaemon, typeof(DreamDaemonRights) },
- { RightsType.ChatSettings, typeof(ChatSettingsRights) },
+ { RightsType.ChatBots, typeof(ChatBotRights) },
{ RightsType.Configuration, typeof(ConfigurationRights) },
{ RightsType.InstanceUser, typeof(InstanceUserRights) }
};
diff --git a/src/Tgstation.Server.Api/Rights/RightsType.cs b/src/Tgstation.Server.Api/Rights/RightsType.cs
index 346f80bcff..5ebd1948e3 100644
--- a/src/Tgstation.Server.Api/Rights/RightsType.cs
+++ b/src/Tgstation.Server.Api/Rights/RightsType.cs
@@ -30,9 +30,9 @@
///
DreamDaemon,
///
- ///
+ ///
///
- ChatSettings,
+ ChatBots,
///
///
///
diff --git a/src/Tgstation.Server.Client/Components/IByondClient.cs b/src/Tgstation.Server.Client/Components/IByondClient.cs
index 8ddbe011f2..bfe9e8f003 100644
--- a/src/Tgstation.Server.Client/Components/IByondClient.cs
+++ b/src/Tgstation.Server.Client/Components/IByondClient.cs
@@ -17,9 +17,9 @@ namespace Tgstation.Server.Client.Components
Task Read(CancellationToken cancellationToken);
///
- /// Updates the installed BYOND
+ /// Updates the information
///
- /// The information to update
+ /// The information to update
/// The for the operation
/// A resulting in the updated information
Task Update(Byond byond, CancellationToken cancellationToken);
diff --git a/src/Tgstation.Server.Client/Components/IChatSettingsClient.cs b/src/Tgstation.Server.Client/Components/IChatBotsClient.cs
similarity index 53%
rename from src/Tgstation.Server.Client/Components/IChatSettingsClient.cs
rename to src/Tgstation.Server.Client/Components/IChatBotsClient.cs
index c0654a6dc2..538fdf72bc 100644
--- a/src/Tgstation.Server.Client/Components/IChatSettingsClient.cs
+++ b/src/Tgstation.Server.Client/Components/IChatBotsClient.cs
@@ -8,37 +8,37 @@ namespace Tgstation.Server.Client.Components
///
/// For managing the chat bots
///
- public interface IChatSettingsClient
+ public interface IChatBotsClient
{
///
- /// List the
+ /// List the
///
/// The for the operation
- /// A resulting in a of the of the server
- Task> List(CancellationToken cancellationToken);
+ /// A resulting in a of the of the server
+ Task> List(CancellationToken cancellationToken);
///
- /// Create a
+ /// Create a
///
- /// The to create
+ /// The to create
/// The for the operation
- /// A resulting in the new
- Task Create(ChatSettings settings, CancellationToken cancellationToken);
+ /// A resulting in the new
+ Task Create(ChatBot settings, CancellationToken cancellationToken);
///
- /// Updates a setttings
+ /// Updates a setttings
///
- /// The to update
+ /// The to update
/// The for the operation
- /// A resulting in the updated
- Task Update(ChatSettings settings, CancellationToken cancellationToken);
+ /// A resulting in the updated
+ Task Update(ChatBot settings, CancellationToken cancellationToken);
///
- /// Delete a
+ /// Delete a
///
- /// The to delete
+ /// The to delete
/// The for the operation
/// A representing the running operation
- Task Delete(ChatSettings settings, CancellationToken cancellationToken);
+ Task Delete(ChatBot settings, CancellationToken cancellationToken);
}
}
diff --git a/src/Tgstation.Server.Client/Components/IConfigurationClient.cs b/src/Tgstation.Server.Client/Components/IConfigurationClient.cs
index af84c1ca73..18cf7c4039 100644
--- a/src/Tgstation.Server.Client/Components/IConfigurationClient.cs
+++ b/src/Tgstation.Server.Client/Components/IConfigurationClient.cs
@@ -1,16 +1,14 @@
-using System;
-using System.Collections.Generic;
+using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;
using Tgstation.Server.Api.Models;
-using Tgstation.Server.Api.Rights;
namespace Tgstation.Server.Client.Components
{
///
/// For managing files
///
- public interface IConfigurationClient : IRightsClient
+ public interface IConfigurationClient
{
///
/// List configuration files
@@ -26,7 +24,7 @@ namespace Tgstation.Server.Client.Components
/// The file to read
/// The for the operation
/// A representing the running operation
- Task Read(ConfigurationFile file, CancellationToken cancellationToken);
+ Task Read(ConfigurationFile file, CancellationToken cancellationToken);
///
/// Overwrite a file with integrity checks
@@ -34,22 +32,6 @@ namespace Tgstation.Server.Client.Components
/// The file to write
/// The for the operation
/// A representing the running operation
- Task Write(ConfigurationFile file, CancellationToken cancellationToken);
-
- ///
- /// Create/overwrite a file
- ///
- /// The file to write
- /// The for the operation
- /// A representing the running operation
- Task Create(ConfigurationFile file, CancellationToken cancellationToken);
-
- ///
- /// Delete a file
- ///
- /// The file to delete
- /// The for the operation
- /// A representing the running operation
- Task Delete(ConfigurationFile file, CancellationToken cancellationToken);
+ Task Write(ConfigurationFile file, CancellationToken cancellationToken);
}
}
diff --git a/src/Tgstation.Server.Client/Components/IDreamDaemonClient.cs b/src/Tgstation.Server.Client/Components/IDreamDaemonClient.cs
index 1947c4170d..2078a954d1 100644
--- a/src/Tgstation.Server.Client/Components/IDreamDaemonClient.cs
+++ b/src/Tgstation.Server.Client/Components/IDreamDaemonClient.cs
@@ -1,14 +1,13 @@
using System.Threading;
using System.Threading.Tasks;
using Tgstation.Server.Api.Models;
-using Tgstation.Server.Api.Rights;
namespace Tgstation.Server.Client.Components
{
///
/// For managing
///
- public interface IDreamDaemonClient: IRightsClient
+ public interface IDreamDaemonClient
{
///
/// Get the represented by the
@@ -22,14 +21,14 @@ namespace Tgstation.Server.Client.Components
///
/// The for the operation
/// A representing the running operation
- Task Start(CancellationToken cancellationToken);
+ Task Start(CancellationToken cancellationToken);
///
/// Shutdown
///
/// The for the operation
/// A representing the running operation
- Task Shutdown(CancellationToken cancellationToken);
+ Task Shutdown(CancellationToken cancellationToken);
///
/// Update . This may trigger
@@ -37,6 +36,6 @@ namespace Tgstation.Server.Client.Components
/// The to update
/// The for the operation
/// A representing the running operation
- Task Update(DreamDaemon dreamDaemon, CancellationToken cancellationToken);
+ Task Update(DreamDaemon dreamDaemon, CancellationToken cancellationToken);
}
}
diff --git a/src/Tgstation.Server.Client/Components/IDreamMakerClient.cs b/src/Tgstation.Server.Client/Components/IDreamMakerClient.cs
index ef1fb7b29b..f9e04a37d4 100644
--- a/src/Tgstation.Server.Client/Components/IDreamMakerClient.cs
+++ b/src/Tgstation.Server.Client/Components/IDreamMakerClient.cs
@@ -8,14 +8,14 @@ namespace Tgstation.Server.Client.Components
///
/// For managing the compiler
///
- public interface IDreamMakerClient : IRightsClient
+ public interface IDreamMakerClient
{
///
/// Get the represented by the
///
/// The for the operation
/// A resulting in the represented by the
- Task Read(CancellationToken cancellationToken);
+ Task Read(CancellationToken cancellationToken);
///
/// Updates the setttings
diff --git a/src/Tgstation.Server.Client/Components/IInstanceClient.cs b/src/Tgstation.Server.Client/Components/IInstanceClient.cs
index e806263fe8..9566815f7a 100644
--- a/src/Tgstation.Server.Client/Components/IInstanceClient.cs
+++ b/src/Tgstation.Server.Client/Components/IInstanceClient.cs
@@ -39,9 +39,9 @@ namespace Tgstation.Server.Client.Components
IInstanceUserClient Users { get; }
///
- /// Access the
+ /// Access the
///
- IChatSettingsClient Chat { get; }
+ IChatBotsClient ChatBots { get; }
///
/// Access the
diff --git a/src/Tgstation.Server.Client/Components/IRepositoryClient.cs b/src/Tgstation.Server.Client/Components/IRepositoryClient.cs
index a3ee2188ad..78259b93c4 100644
--- a/src/Tgstation.Server.Client/Components/IRepositoryClient.cs
+++ b/src/Tgstation.Server.Client/Components/IRepositoryClient.cs
@@ -2,14 +2,13 @@
using System.Threading;
using System.Threading.Tasks;
using Tgstation.Server.Api.Models;
-using Tgstation.Server.Api.Rights;
namespace Tgstation.Server.Client.Components
{
///
/// For managing the
///
- public interface IRepositoryClient : IRightsClient
+ public interface IRepositoryClient
{
///
/// Get the represented by the
diff --git a/src/Tgstation.Server.Host/Components/Chat/Chat.cs b/src/Tgstation.Server.Host/Components/Chat/Chat.cs
index 15121806f3..983155cad5 100644
--- a/src/Tgstation.Server.Host/Components/Chat/Chat.cs
+++ b/src/Tgstation.Server.Host/Components/Chat/Chat.cs
@@ -44,7 +44,7 @@ namespace Tgstation.Server.Host.Components.Chat
readonly Dictionary builtinCommands;
///
- /// Map of s in use, keyed by
+ /// Map of s in use, keyed by
///
readonly Dictionary providers;
@@ -64,9 +64,9 @@ namespace Tgstation.Server.Host.Components.Chat
readonly CancellationTokenSource handlerCts;
///
- /// The initial for the
+ /// The initial for the
///
- readonly List initialChatSettings;
+ readonly List initialChatBots;
///
/// The for the
@@ -79,7 +79,7 @@ namespace Tgstation.Server.Host.Components.Chat
Task chatHandler;
///
- /// The that completes when change
+ /// The that completes when s change
///
TaskCompletionSource
diff --git a/src/Tgstation.Server.Client/Components/IInstanceUserClient.cs b/src/Tgstation.Server.Client/Components/IInstanceUserClient.cs
index 65248e42d5..6c73e0371f 100644
--- a/src/Tgstation.Server.Client/Components/IInstanceUserClient.cs
+++ b/src/Tgstation.Server.Client/Components/IInstanceUserClient.cs
@@ -2,14 +2,13 @@
using System.Threading;
using System.Threading.Tasks;
using Tgstation.Server.Api.Models;
-using Tgstation.Server.Api.Rights;
namespace Tgstation.Server.Client.Components
{
///
/// For managing s
///
- public interface IInstanceUserClient : IRightsClient
+ public interface IInstanceUserClient
{
///
/// Get the s in the
@@ -18,12 +17,20 @@ namespace Tgstation.Server.Client.Components
/// A resulting in a of s in the instance
Task> Read(CancellationToken cancellationToken);
- ///
- /// Update a
- ///
- /// The to update
- /// The for the operation
- /// A representing the running operation
- Task Update(InstanceUser instanceUser, CancellationToken cancellationToken);
- }
+ ///
+ /// Update a
+ ///
+ /// The to update
+ /// The for the operation
+ /// A representing the running operation
+ Task Update(InstanceUser instanceUser, CancellationToken cancellationToken);
+
+ ///
+ /// Create a
+ ///
+ /// The to create
+ /// The for the operation
+ /// A representing the running operation
+ Task Create(InstanceUser instanceUser, CancellationToken cancellationToken);
+ }
}
\ No newline at end of file